/* messageview.c */

#include <glib.h>
#include <gtk/gtkvpaned.h>
#include <gtk/gtkeditable.h>
#include <stdio.h>
#include <ctype.h>
#include <string.h>

#include "main.h"
#include "messageview.h"
#include "headerview.h"
#include "textview.h"
#include "mimeview.h"
#include "utils.h"

MessageView *messageview_create(void)
{
	MessageView *messageview;
	GtkWidget *paned;
	HeaderView *headerview;
	TextView *textview;
	//MimeView *mimeview;

	debug_print(_("Creating message view...\n"));
	messageview = g_new0(MessageView, 1);

	messageview->type = MVIEW_TEXT;

	headerview = headerview_create();

	textview = textview_create();
	textview->messageview = messageview;

	//mimeview = mimeview_create();

	paned = gtk_vpaned_new();
	gtk_paned_add1(GTK_PANED(paned), *(GtkWidget **)headerview);
	gtk_paned_add2(GTK_PANED(paned), *(GtkWidget **)textview);

	/* to remove without destroyed */
	gtk_widget_ref(*(GtkWidget **)textview);
	//gtk_widget_ref(*(GtkWidget **)mimeview);

	messageview->paned      = paned;
	messageview->headerview = headerview;
	messageview->textview   = textview;
	//messageview->mimeview = mimeview;

	return messageview;
}

void messageview_init(MessageView *messageview)
{
	headerview_init(messageview->headerview);
	textview_init(messageview->textview);
	//mimeview_init(messageview->mimeview);
	messageview_set_font();
}

void messageview_show(MessageView *messageview, const gchar *file)
{
	textview_show_message(messageview->textview, file);
}

void messageview_quote_color_set(void)
{
}

void messageview_set_font(void)
{
	textview_set_font();
}

void messageview_copy_clipboard(MessageView *messageview)
{
	if (messageview->type == MVIEW_TEXT)
		gtk_editable_copy_clipboard
			(GTK_EDITABLE(messageview->textview->text));
}

void messageview_select_all(MessageView *messageview)
{
	if (messageview->type == MVIEW_TEXT)
		gtk_editable_select_region
			(GTK_EDITABLE(messageview->textview->text), 0, -1);
}

GtkWidget *messageview_get_text_widget(MessageView *messageview)
{
	if (messageview->type == MVIEW_TEXT)
		return messageview->textview->text;
	else
		return NULL;
}
