/* procmime.c */

#include <glib.h>
#include <string.h>

#include "procmime.h"
#include "utils.h"

MimeInfo *procmime_mimeinfo_new(void)
{
	MimeInfo *mimeinfo;

	mimeinfo = g_new0(MimeInfo, 1);
	mimeinfo->mime_type     = MIME_UNKNOWN;
	mimeinfo->encoding_type = ENC_UNKNOWN;

	return mimeinfo;
}

void procmime_mimeinfo_free(MimeInfo *mimeinfo)
{
	if (!mimeinfo) return;

	g_free(mimeinfo->encoding);
	g_free(mimeinfo->content_type);
	g_free(mimeinfo->charset);
	g_free(mimeinfo);
}

void procmime_scan_encoding(MimeInfo *mimeinfo, const gchar *encoding)
{
	gchar *buf;

	Xalloca(buf, strlen(encoding), return);
	strcpy(buf, encoding);

	g_free(mimeinfo->encoding);

	mimeinfo->encoding = g_strdup(g_strstrip(buf));
	if (!strcasecmp(buf, "7bit"))
		mimeinfo->encoding_type = ENC_7BIT;
	else if (!strcasecmp(buf, "quoted-printable"))
		mimeinfo->encoding_type = ENC_QUOTED_PRINTABLE;
	else if (!strcasecmp(buf, "base64"))
		mimeinfo->encoding_type = ENC_BASE64;
	else
		mimeinfo->encoding_type = ENC_UNKNOWN;

}

void procmime_scan_content_type(MimeInfo *mimeinfo, const gchar *content_type)
{
	gchar *delim, *cnttype;
	gchar *buf;

	Xalloca(buf, strlen(content_type), return);
	strcpy(buf, content_type);

	g_free(mimeinfo->content_type);
	g_free(mimeinfo->charset);
	mimeinfo->content_type = NULL;
	mimeinfo->charset = NULL;

	if ((delim = strchr(buf, ';')) == NULL) {
		mimeinfo->content_type = g_strdup(g_strstrip(buf));
		//mimeinfo->charset = g_strdup("US-ASCII");
	} else {
		gchar *p;

		*delim = '\0';
		mimeinfo->content_type = g_strdup(g_strstrip(buf));
		if ((p = strcasestr(delim + 1, "charset")) != NULL &&
		    (p = strchr(p, '=')) != NULL) {
			p++;
			eliminate_parenthesis(p, '(', ')');
			p = g_strstrip(p);
			if (*p == '"') extract_quote(p, '"');
			mimeinfo->charset = g_strdup(p);
		}
	}

	cnttype = mimeinfo->content_type;

	if (!strncasecmp(cnttype, "text/", 5) ||
	    !strncasecmp(cnttype, "message/rfc822", 14))
		mimeinfo->mime_type = MIME_TEXT;
	else if (!strncasecmp(cnttype, "application/", 12))
		mimeinfo->mime_type = MIME_APPLICATION;
	else if (!strncasecmp(cnttype, "multipart/", 10))
		mimeinfo->mime_type = MIME_MULTIPART;
	else
		mimeinfo->mime_type = MIME_UNKNOWN;
}
